@@ -192,6 +192,9 @@ class LsystemWidget(PGLWidget):
             self.is_magic = True
             code_ = code
 
+        if not code_:
+            raise ValueError('Neither lpy file nor code provided')
+
         self.__codes = code_.split(lpy.LpyParsing.InitialisationBeginTag)
         self.__codes.insert(1, f'\n{lpy.LpyParsing.InitialisationBeginTag}\n')
 
@@ -228,23 +231,35 @@ class LsystemWidget(PGLWidget):
         else:
             return None
 
+    def get_lstring(self):
+        if self.__derivationStep < len(self.__trees):
+            return lpy.Lstring(self.__trees[self.__derivationStep])
+        return lpy.Lstring()
+
+    def get_namespace(self):
+        result = {}
+        result.update(self.__lsystem.context().globals())
+        return result
+
     def __initialize_lsystem(self):
         self.__lsystem.filename = self.__filename if self.__filename else ''
         self.__lsystem.set(''.join(self.__codes), self.__extra_context)
         # context = self.__lsystem.context()
         # for key, value in self.__extra_context.items():
         #     context[key] = value
-        self.derivationLength = self.__lsystem.derivationLength
-        self.__trees = []
-        self.__trees.append(self.__lsystem.axiom)
+        self.derivationLength = self.__lsystem.derivationLength + 1
+        self.__trees = [self.__lsystem.axiom]
 
     def __on_lpy_context_change(self, context_obj):
         if not self.animate:
-            self.__codes[2] = self.__initialisation_function(context_obj)
+            if len(self.__codes) == 2:
+                self.__codes.append(self.__initialisation_function(context_obj))
+            else:
+                self.__codes[2] = self.__initialisation_function(context_obj)
             self.__lsystem.clear()
             self.__lsystem.filename = self.__filename
             self.__lsystem.set(''.join(self.__codes), {})
-            self.derivationLength = self.__lsystem.derivationLength
+            self.derivationLength = self.__lsystem.derivationLength + 1
             self.__trees = []
             self.__trees.append(self.__lsystem.axiom)
             self.__derivationStep = self.__derivationStep if self.__derivationStep < self.derivationLength else self.derivationLength - 1
